summaryrefslogtreecommitdiffstats
path: root/generic/tclCompile.c
diff options
context:
space:
mode:
authordgp <dgp@users.sourceforge.net>2011-04-21 13:47:48 (GMT)
committerdgp <dgp@users.sourceforge.net>2011-04-21 13:47:48 (GMT)
commit7522eeff966d066c292c39a89986a78922d65f73 (patch)
tree6159f577b200fa32f4575a1ead43307fa7ff8f7f /generic/tclCompile.c
parent00ffa6c31944e0537fefd0dd70ca3aded31e6336 (diff)
parent842312f3957922d5d3255fd5d2a511220f26c748 (diff)
downloadtcl-7522eeff966d066c292c39a89986a78922d65f73.zip
tcl-7522eeff966d066c292c39a89986a78922d65f73.tar.gz
tcl-7522eeff966d066c292c39a89986a78922d65f73.tar.bz2
Make sure SetFooFromAny routines react reasonably when passed a NULL interp.
Diffstat (limited to 'generic/tclCompile.c')
-rw-r--r--generic/tclCompile.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/generic/tclCompile.c b/generic/tclCompile.c
index 3330315..2194ae1 100644
--- a/generic/tclCompile.c
+++ b/generic/tclCompile.c
@@ -509,12 +509,13 @@ static const Tcl_ObjType tclInstNameType = {
* generate an byte code internal form for the Tcl object "objPtr" by
* compiling its string representation. This function also takes a hook
* procedure that will be invoked to perform any needed post processing
* on the compilation results before generating byte codes.
*
* Results:
* The return value is a standard Tcl object result. If an error occurs
* during compilation, an error message is left in the interpreter's
- * result unless "interp" is NULL.
+ * result.
*
* Side effects:
* Frees the old internal representation. If no error occurs, then the
@@ -672,6 +673,9 @@ SetByteCodeFromAny(
* compiled. Must not be NULL. */
Tcl_Obj *objPtr) /* The object to make a ByteCode object. */
{
+ if (interp == NULL) {
+ return TCL_ERROR;
+ }
TclSetByteCodeFromAny(interp, objPtr, NULL, NULL);
return TCL_OK;
}
@@ -509,12 +509,13 @@ static const Tcl_ObjType tclInstNameType = {
* compiling its string representation. This function also takes a hook
* procedure that will be invoked to perform any needed post processing
- * on the compilation results before generating byte codes.
+ * on the compilation results before generating byte codes. interp is
+ * compilation context and may not be NULL.
*
* Results: